{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "id": "fefa868f",
   "metadata": {},
   "outputs": [],
   "source": [
    "%load_ext autoreload\n",
    "%autoreload 2"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "id": "1dea7784",
   "metadata": {},
   "outputs": [],
   "source": [
    "import math\n",
    "import numpy as np\n",
    "import string\n",
    "from string import ascii_lowercase\n",
    "import multiway_decision_tree as mdt\n",
    "from sklearn.model_selection import train_test_split\n",
    "import sklearn\n",
    "from sklearn.svm import LinearSVC\n",
    "import pickle"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "id": "f4d4b1ca",
   "metadata": {},
   "outputs": [],
   "source": [
    "class Split_actor:\n",
    "    def __init__( self, attr ):\n",
    "        self.attr = attr\n",
    "        \n",
    "    def get_attr( self ):\n",
    "        return self.attr\n",
    "    \n",
    "    def split( self, tst_pt, ancestors ):\n",
    "        if len( ancestors ) == 0:\n",
    "            mask = input( \"Start  : \" )\n",
    "        else:\n",
    "            mask = input( \"Guess \" + str( self.attr ) + \": \" )\n",
    "        \n",
    "        # Splitting a single point so the dictionary is trivial\n",
    "        split_dict = {}\n",
    "        split_dict[ mask ] = ( [ 0 ], [ mask ] )\n",
    "        \n",
    "        return split_dict\n",
    "        \n",
    "    def default_predict( self, tst_pt, ancestors ):\n",
    "        return [ None ]\n",
    "    \n",
    "class Leaf_actor:\n",
    "    def __init__( self, data ):\n",
    "        self.data = data\n",
    "        \n",
    "    def predict( self, tst_pt, ancestors ):\n",
    "        return [ self.data[0] ]\n",
    "        \n",
    "    def default_predict( self, tst_pt, ancestors ):\n",
    "        return [ None ]\n",
    "\n",
    "def get_size( trn_pts ):\n",
    "    return len( trn_pts )\n",
    "\n",
    "def is_pure_enough( trn_pts ):\n",
    "    if len( trn_pts ) < 2:\n",
    "        return True\n",
    "    else:\n",
    "        return False\n",
    "\n",
    "def get_leaf_actor( trn_pts, ancestors ):\n",
    "    return Leaf_actor( data = trn_pts )\n",
    "\n",
    "# See the following StackOverflow conversation on some alternate ways to compute entropy\n",
    "# https://stackoverflow.com/questions/15450192/fastest-way-to-compute-entropy-in-python\n",
    "def get_entropy( counts ):    \n",
    "    # Why include elements that do not appear at all?\n",
    "    assert np.min( counts ) > 0, \"Elements with zero or negative counts detected\"\n",
    "    \n",
    "    num_elements = counts.sum()\n",
    "    \n",
    "    # A singular or empty set has zero entropy\n",
    "    if num_elements <= 1:\n",
    "        print( f\"warning: { num_elements } elements in total.\" )\n",
    "        return 0\n",
    "    \n",
    "    proportions = counts / num_elements\n",
    "    \n",
    "    return np.sum( proportions * np.log2( counts ) )  \n",
    "\n",
    "def get_mask( char_list, word ):\n",
    "    mask = []\n",
    "    \n",
    "    for c in word:\n",
    "        if c in char_list:\n",
    "            mask.append( c )\n",
    "        else:\n",
    "            mask.append( '_' )\n",
    "    \n",
    "    return ' '.join( mask )\n",
    "\n",
    "def try_attr( char_list, words ):\n",
    "    split_dict = {}\n",
    "    count_dict = {}\n",
    "    \n",
    "    for word in words:\n",
    "        mask = get_mask( char_list, word )\n",
    "        \n",
    "        if mask not in split_dict:\n",
    "            split_dict[ mask ] = []\n",
    "            count_dict[ mask ] = 0\n",
    "            \n",
    "        split_dict[ mask ].append( word )\n",
    "        count_dict[ mask ] += 1\n",
    "\n",
    "    entropy = get_entropy( np.array( list( count_dict.values() ) ) )\n",
    "    \n",
    "    return ( entropy, split_dict )\n",
    "\n",
    "def get_split_actor( trn_pts, ancestors ):\n",
    "    \n",
    "    # If this is the root node, we must split on word length\n",
    "    if len( ancestors ) == 0:\n",
    "        ( entropy, split_dict ) = try_attr( [], trn_pts )\n",
    "        return ( Split_actor( \"len\" ), split_dict )\n",
    "        \n",
    "    # Exclude the first element of the ancestry since that is the length split\n",
    "    ancestor_attr = [ split[0] for split in ancestors ][1:]\n",
    "    \n",
    "    best_entropy = np.inf\n",
    "    best_attr = ''\n",
    "    best_split_dict = None\n",
    "    \n",
    "    for c in [ char for char in ascii_lowercase if char not in ancestor_attr ]:\n",
    "        char_list = ancestor_attr.copy()\n",
    "        char_list.append( c )\n",
    "        ( entropy, split_dict ) = try_attr( char_list, trn_pts )\n",
    "#         print( f\"{c}({entropy})\", end = \", \" )\n",
    "        if entropy < best_entropy:\n",
    "            best_entropy = entropy\n",
    "            best_attr = c\n",
    "            best_split_dict = split_dict\n",
    "    \n",
    "#     print()\n",
    "#     print( f\"-->{best_attr}({best_entropy})\\n\" )\n",
    "    \n",
    "    return ( Split_actor( best_attr ), best_split_dict )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "id": "2678525d",
   "metadata": {
    "scrolled": true
   },
   "outputs": [],
   "source": [
    "f = open( \"base\", 'r' )\n",
    "words = f.read().split( '\\n' )[:-1]        # Omit the last line since it is empty\n",
    "f.close()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "id": "c321ec41",
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "root\n",
      "└───len\n",
      "    ├───e\n",
      "    │   ├───a\n",
      "    │   │   ├───g\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───c\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───k\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───i\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───t\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───f\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───k\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───r\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───o\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───d\n",
      "    │   │   │   │   │       ├───h\n",
      "    │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │       └───h\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───o\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───m\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───m\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───t\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───h\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───u\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───o\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───h\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───m\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───s\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───m\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───c\n",
      "    │   │       ├───█\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───g\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───p\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───s\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───f\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───i\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───o\n",
      "    │   │       ├───█\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───i\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───d\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───p\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───a\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   ├───h\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───g\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───d\n",
      "    │   │   │   │       ├───f\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───m\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───m\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───v\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───k\n",
      "    │   │   │   │   │   ├───m\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───p\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───h\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───o\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───a\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───b\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───u\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───h\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───l\n",
      "    │   │   ├───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───f\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───i\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───h\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───a\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───v\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───g\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───n\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───b\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───g\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───n\n",
      "    │   │   │           ├───█\n",
      "    │   │   │           └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───l\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───a\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───h\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───s\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───h\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───v\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───g\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   └───s\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───i\n",
      "    │   │       ├───d\n",
      "    │   │       │   ├───█\n",
      "    │   │       │   ├───a\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   └───█\n",
      "    │   │       │   └───█\n",
      "    │   │       ├───a\n",
      "    │   │       │   ├───█\n",
      "    │   │       │   └───█\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───d\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───f\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   └───█\n",
      "    ├───e\n",
      "    │   ├───r\n",
      "    │   │   ├───n\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───i\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───f\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───d\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───a\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───l\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───o\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   │   ├───s\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   └───v\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───f\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───f\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───b\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───c\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───d\n",
      "    │   │       ├───█\n",
      "    │   │       └───i\n",
      "    │   │           ├───█\n",
      "    │   │           └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───g\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───r\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───d\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───d\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───g\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───l\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───l\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───b\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───m\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───p\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───h\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───j\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───n\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───d\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───i\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───t\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───r\n",
      "    │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───l\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───m\n",
      "    │   │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───m\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───t\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───n\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───k\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   ├───r\n",
      "    │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───n\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───g\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───r\n",
      "    │   │   │   │   │   ├───t\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───k\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───n\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───b\n",
      "    │   │   │   │   │   │   │       ├───d\n",
      "    │   │   │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───v\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───u\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───l\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │       ├───k\n",
      "    │   │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───s\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───h\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───d\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───f\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───g\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───t\n",
      "    │   │   │   │       ├───d\n",
      "    │   │   │   │       │   ├───c\n",
      "    │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │       │   │   └───█\n",
      "    │   │   │   │       │   └───g\n",
      "    │   │   │   │       │       ├───█\n",
      "    │   │   │   │       │       └───█\n",
      "    │   │   │   │       ├───h\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───m\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───█\n",
      "    │   │   │   ├───p\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───r\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───n\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───m\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───s\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───s\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───n\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───i\n",
      "    │   │   │   │   │       ├───b\n",
      "    │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │       └───j\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───r\n",
      "    │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───m\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───s\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───p\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       ├───r\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───i\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───i\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───r\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───i\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───n\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       ├───l\n",
      "    │   │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │   │       └───d\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───g\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───l\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───f\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───g\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───d\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───i\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───l\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───c\n",
      "    │   │   │       ├───i\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───b\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───t\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───p\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───c\n",
      "    │   │   │       ├───g\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───i\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───u\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───i\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───k\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───p\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───g\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───k\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───i\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───u\n",
      "    │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───q\n",
      "    │   │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───n\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───w\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───t\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   └───p\n",
      "    │   │   │   │   │       ├───c\n",
      "    │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │       └───k\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───i\n",
      "    │   │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───m\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───p\n",
      "    │   │   │   │   │   ├───t\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───i\n",
      "    │   │   │   │   │       ├───c\n",
      "    │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │       │   └───m\n",
      "    │   │   │   │   │       │       ├───█\n",
      "    │   │   │   │   │       │       └───█\n",
      "    │   │   │   │   │       └───b\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───n\n",
      "    │   │   │   │   │               ├───█\n",
      "    │   │   │   │   │               └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───f\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───h\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───n\n",
      "    │   │   │   │               ├───█\n",
      "    │   │   │   │               └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───d\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───f\n",
      "    │   │   │           ├───█\n",
      "    │   │   │           └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───m\n",
      "    │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───n\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───g\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───k\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │       ├───d\n",
      "    │   │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───d\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───p\n",
      "    │   │   │   │   ├───t\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───k\n",
      "    │   │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───m\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───g\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───s\n",
      "    │   │       ├───l\n",
      "    │   │       │   ├───c\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   └───█\n",
      "    │   │       │   ├───c\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   └───g\n",
      "    │   │       │   │       ├───█\n",
      "    │   │       │   │       ├───█\n",
      "    │   │       │   │       └───█\n",
      "    │   │       │   ├───█\n",
      "    │   │       │   └───u\n",
      "    │   │       │       ├───█\n",
      "    │   │       │       └───█\n",
      "    │   │       ├───u\n",
      "    │   │       │   ├───c\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   └───█\n",
      "    │   │       │   └───f\n",
      "    │   │       │       ├───█\n",
      "    │   │       │       └───█\n",
      "    │   │       ├───█\n",
      "    │   │       └───t\n",
      "    │   │           ├───█\n",
      "    │   │           └───█\n",
      "    │   ├───a\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "    │   │   ├───d\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───p\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───w\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───d\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───h\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───g\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───l\n",
      "    │   │   │       ├───c\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───h\n",
      "    │   │   │           ├───█\n",
      "    │   │   │           └───m\n",
      "    │   │   │               ├───█\n",
      "    │   │   │               └───p\n",
      "    │   │   │                   ├───█\n",
      "    │   │   │                   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───l\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───j\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───a\n",
      "    │   │   │   │       ├───c\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───a\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───h\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───d\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───a\n",
      "    │   │       ├───n\n",
      "    │   │       │   ├───█\n",
      "    │   │       │   └───█\n",
      "    │   │       └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───f\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───p\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───n\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───t\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───h\n",
      "    │   │   │       ├───k\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───n\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───d\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   └───c\n",
      "    │   │       ├───█\n",
      "    │   │       └───h\n",
      "    │   │           ├───█\n",
      "    │   │           └───█\n",
      "    │   ├───s\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───l\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───d\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───n\n",
      "    │   │   │           ├───█\n",
      "    │   │   │           └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───v\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───l\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───f\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───v\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───j\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───l\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───l\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───h\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───i\n",
      "    │   │   │   │       ├───j\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───t\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   └───s\n",
      "    │       ├───h\n",
      "    │       │   ├───c\n",
      "    │       │   │   ├───█\n",
      "    │       │   │   └───█\n",
      "    │       │   └───m\n",
      "    │       │       ├───█\n",
      "    │       │       └───t\n",
      "    │       │           ├───█\n",
      "    │       │           └───█\n",
      "    │       ├───c\n",
      "    │       │   ├───█\n",
      "    │       │   └───█\n",
      "    │       └───█\n",
      "    ├───e\n",
      "    │   ├───r\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───i\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───m\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───p\n",
      "    │   │   │   │   │   │               ├───█\n",
      "    │   │   │   │   │   │               └───█\n",
      "    │   │   │   │   │   └───h\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───m\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───p\n",
      "    │   │   │   │   │               ├───█\n",
      "    │   │   │   │   │               └───█\n",
      "    │   │   │   │   └───m\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───p\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───s\n",
      "    │   │   │   │               ├───█\n",
      "    │   │   │   │               └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───o\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───m\n",
      "    │   │   │   │   │   │   │   │   ├───s\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───g\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │       ├───n\n",
      "    │   │   │   │   │   │       │   ├───g\n",
      "    │   │   │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │   │   │       │   │   └───█\n",
      "    │   │   │   │   │   │       │   ├───f\n",
      "    │   │   │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │   │   │       │   │   └───█\n",
      "    │   │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │   │       ├───i\n",
      "    │   │   │   │   │   │       │   ├───n\n",
      "    │   │   │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │   │   │       │   │   └───█\n",
      "    │   │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │   │       └───h\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───s\n",
      "    │   │   │   │   │   │               ├───█\n",
      "    │   │   │   │   │   │               └───█\n",
      "    │   │   │   │   │   ├───n\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───m\n",
      "    │   │   │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───i\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───k\n",
      "    │   │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   │   └───n\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   └───d\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───f\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───g\n",
      "    │   │   │   │   │               ├───█\n",
      "    │   │   │   │   │               └───h\n",
      "    │   │   │   │   │                   ├───█\n",
      "    │   │   │   │   │                   └───█\n",
      "    │   │   │   │   └───a\n",
      "    │   │   │   │       ├───k\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───i\n",
      "    │   │   │   │           ├───d\n",
      "    │   │   │   │           │   ├───█\n",
      "    │   │   │   │           │   └───█\n",
      "    │   │   │   │           └───n\n",
      "    │   │   │   │               ├───o\n",
      "    │   │   │   │               │   ├───█\n",
      "    │   │   │   │               │   └───█\n",
      "    │   │   │   │               └───b\n",
      "    │   │   │   │                   ├───█\n",
      "    │   │   │   │                   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───a\n",
      "    │   │   │       ├───c\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───k\n",
      "    │   │   │       │       ├───█\n",
      "    │   │   │       │       └───n\n",
      "    │   │   │       │           ├───█\n",
      "    │   │   │       │           └───█\n",
      "    │   │   │       └───i\n",
      "    │   │   │           ├───f\n",
      "    │   │   │           │   ├───█\n",
      "    │   │   │           │   └───k\n",
      "    │   │   │           │       ├───█\n",
      "    │   │   │           │       └───n\n",
      "    │   │   │           │           ├───█\n",
      "    │   │   │           │           └───█\n",
      "    │   │   │           └───n\n",
      "    │   │   │               ├───█\n",
      "    │   │   │               └───s\n",
      "    │   │   │                   ├───█\n",
      "    │   │   │                   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───d\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───█\n",
      "    │   │   │   └───i\n",
      "    │   │   │       ├───o\n",
      "    │   │   │       │   ├───c\n",
      "    │   │   │       │   │   ├───█\n",
      "    │   │   │       │   │   └───m\n",
      "    │   │   │       │   │       ├───█\n",
      "    │   │   │       │   │       └───█\n",
      "    │   │   │       │   └───c\n",
      "    │   │   │       │       ├───█\n",
      "    │   │   │       │       └───p\n",
      "    │   │   │       │           ├───█\n",
      "    │   │   │       │           └───s\n",
      "    │   │   │       │               ├───█\n",
      "    │   │   │       │               └───█\n",
      "    │   │   │       └───f\n",
      "    │   │   │           ├───█\n",
      "    │   │   │           └───h\n",
      "    │   │   │               ├───█\n",
      "    │   │   │               └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───g\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───p\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───█\n",
      "    │   │   │   └───i\n",
      "    │   │   │       ├───c\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───d\n",
      "    │   │   │       │       ├───█\n",
      "    │   │   │       │       └───█\n",
      "    │   │   │       └───l\n",
      "    │   │   │           ├───o\n",
      "    │   │   │           │   ├───█\n",
      "    │   │   │           │   └───█\n",
      "    │   │   │           └───d\n",
      "    │   │   │               ├───p\n",
      "    │   │   │               │   ├───█\n",
      "    │   │   │               │   └───█\n",
      "    │   │   │               └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───g\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───l\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───t\n",
      "    │   │   │   │   │   │   ├───o\n",
      "    │   │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───m\n",
      "    │   │   │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───y\n",
      "    │   │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───o\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───i\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───g\n",
      "    │   │   │   │   │   │   │   ├───t\n",
      "    │   │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │       ├───i\n",
      "    │   │   │   │   │   │       │   ├───b\n",
      "    │   │   │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │   │   │       │   │   └───█\n",
      "    │   │   │   │   │   │       │   └───f\n",
      "    │   │   │   │   │   │       │       ├───█\n",
      "    │   │   │   │   │   │       │       └───█\n",
      "    │   │   │   │   │   │       └───t\n",
      "    │   │   │   │   │   │           ├───h\n",
      "    │   │   │   │   │   │           │   ├───█\n",
      "    │   │   │   │   │   │           │   └───█\n",
      "    │   │   │   │   │   │           ├───k\n",
      "    │   │   │   │   │   │           │   ├───█\n",
      "    │   │   │   │   │   │           │   ├───█\n",
      "    │   │   │   │   │   │           │   └───█\n",
      "    │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   ├───o\n",
      "    │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───g\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───w\n",
      "    │   │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │   │       ├───█\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "    │   │   │   │   │   │   │       └───g\n",
      "    │   │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───o\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───k\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───t\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───i\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───m\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   └───i\n",
      "    │   │   │   │   │       ├───b\n",
      "    │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │       │   └───f\n",
      "    │   │   │   │   │       │       ├───█\n",
      "    │   │   │   │   │       │       └───█\n",
      "    │   │   │   │   │       └───k\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   ├───t\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───h\n",
      "    │   │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │       ├───c\n",
      "    │   │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │   │       │   └───d\n",
      "    │   │   │   │   │   │       │       ├───█\n",
      "    │   │   │   │   │   │       │       └───█\n",
      "    │   │   │   │   │   │       └───g\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───p\n",
      "    │   │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   │   └───o\n",
      "    │   │   │   │   │   │       ├───c\n",
      "    │   │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │   │       │   └───h\n",
      "    │   │   │   │   │   │       │       ├───█\n",
      "    │   │   │   │   │   │       │       └───█\n",
      "    │   │   │   │   │   │       └───i\n",
      "    │   │   │   │   │   │           ├───d\n",
      "    │   │   │   │   │   │           │   ├───█\n",
      "    │   │   │   │   │   │           │   └───█\n",
      "    │   │   │   │   │   │           └───f\n",
      "    │   │   │   │   │   │               ├───█\n",
      "    │   │   │   │   │   │               └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───o\n",
      "    │   │   │   │       ├───i\n",
      "    │   │   │   │       │   ├───a\n",
      "    │   │   │   │       │   │   ├───c\n",
      "    │   │   │   │       │   │   │   ├───█\n",
      "    │   │   │   │       │   │   │   └───█\n",
      "    │   │   │   │       │   │   ├───n\n",
      "    │   │   │   │       │   │   │   ├───█\n",
      "    │   │   │   │       │   │   │   ├───█\n",
      "    │   │   │   │       │   │   │   └───t\n",
      "    │   │   │   │       │   │   │       ├───█\n",
      "    │   │   │   │       │   │   │       └───█\n",
      "    │   │   │   │       │   │   └───h\n",
      "    │   │   │   │       │   │       ├───█\n",
      "    │   │   │   │       │   │       ├───█\n",
      "    │   │   │   │       │   │       └───█\n",
      "    │   │   │   │       │   ├───p\n",
      "    │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │       │   │   ├───k\n",
      "    │   │   │   │       │   │   │   ├───█\n",
      "    │   │   │   │       │   │   │   └───m\n",
      "    │   │   │   │       │   │   │       ├───█\n",
      "    │   │   │   │       │   │   │       └───█\n",
      "    │   │   │   │       │   │   └───n\n",
      "    │   │   │   │       │   │       ├───█\n",
      "    │   │   │   │       │   │       └───█\n",
      "    │   │   │   │       │   └───g\n",
      "    │   │   │   │       │       ├───c\n",
      "    │   │   │   │       │       │   ├───█\n",
      "    │   │   │   │       │       │   └───█\n",
      "    │   │   │   │       │       ├───h\n",
      "    │   │   │   │       │       │   ├───█\n",
      "    │   │   │   │       │       │   └───█\n",
      "    │   │   │   │       │       └───█\n",
      "    │   │   │   │       ├───p\n",
      "    │   │   │   │       │   ├───h\n",
      "    │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │       │   │   └───█\n",
      "    │   │   │   │       │   ├───h\n",
      "    │   │   │   │       │   │   ├───t\n",
      "    │   │   │   │       │   │   │   ├───█\n",
      "    │   │   │   │       │   │   │   └───█\n",
      "    │   │   │   │       │   │   └───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       ├───a\n",
      "    │   │   │   │       │   ├───k\n",
      "    │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │       │   │   └───█\n",
      "    │   │   │   │       │   ├───c\n",
      "    │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │       │   │   └───f\n",
      "    │   │   │   │       │   │       ├───█\n",
      "    │   │   │   │       │   │       └───g\n",
      "    │   │   │   │       │   │           ├───█\n",
      "    │   │   │   │       │   │           └───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───p\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───m\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───t\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───d\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───i\n",
      "    │   │   │   │       ├───a\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───d\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───m\n",
      "    │   │   │   │               ├───█\n",
      "    │   │   │   │               └───n\n",
      "    │   │   │   │                   ├───█\n",
      "    │   │   │   │                   └───█\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───y\n",
      "    │   │   │   │   │   │   ├───m\n",
      "    │   │   │   │   │   │   │   ├───t\n",
      "    │   │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───v\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───h\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───w\n",
      "    │   │   │   │   │   │               ├───█\n",
      "    │   │   │   │   │   │               └───█\n",
      "    │   │   │   │   │   └───a\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───w\n",
      "    │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───p\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───k\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───k\n",
      "    │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───m\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───a\n",
      "    │   │   │   │       ├───h\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───p\n",
      "    │   │   │   │       │       ├───█\n",
      "    │   │   │   │       │       └───t\n",
      "    │   │   │   │       │           ├───█\n",
      "    │   │   │   │       │           └───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───i\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───g\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───f\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───m\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───a\n",
      "    │   │   │   │   │   │       ├───n\n",
      "    │   │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───a\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───a\n",
      "    │   │   │       ├───b\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───m\n",
      "    │   │   │       │       ├───█\n",
      "    │   │   │       │       └───█\n",
      "    │   │   │       └───i\n",
      "    │   │   │           ├───m\n",
      "    │   │   │           │   ├───█\n",
      "    │   │   │           │   └───█\n",
      "    │   │   │           └───t\n",
      "    │   │   │               ├───█\n",
      "    │   │   │               └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───f\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───j\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───m\n",
      "    │   │   │   │   │               ├───█\n",
      "    │   │   │   │   │               └───n\n",
      "    │   │   │   │   │                   ├───█\n",
      "    │   │   │   │   │                   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───i\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───i\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───f\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───p\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───t\n",
      "    │   │   │   │               ├───█\n",
      "    │   │   │   │               └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───f\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───g\n",
      "    │   │   │   │   │               ├───█\n",
      "    │   │   │   │   │               └───h\n",
      "    │   │   │   │   │                   ├───█\n",
      "    │   │   │   │   │                   └───█\n",
      "    │   │   │   │   └───o\n",
      "    │   │   │   │       ├───b\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───d\n",
      "    │   │   │   │       │       ├───█\n",
      "    │   │   │   │       │       └───f\n",
      "    │   │   │   │       │           ├───█\n",
      "    │   │   │   │       │           └───█\n",
      "    │   │   │   │       └───d\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───p\n",
      "    │   │   │   │               ├───█\n",
      "    │   │   │   │               └───r\n",
      "    │   │   │   │                   ├───█\n",
      "    │   │   │   │                   └───█\n",
      "    │   │   │   └───b\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───f\n",
      "    │   │   │           ├───█\n",
      "    │   │   │           └───h\n",
      "    │   │   │               ├───█\n",
      "    │   │   │               └───k\n",
      "    │   │   │                   ├───█\n",
      "    │   │   │                   └───m\n",
      "    │   │   │                       ├───█\n",
      "    │   │   │                       └───p\n",
      "    │   │   │                           ├───█\n",
      "    │   │   │                           └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───h\n",
      "    │   │   │   │   │       ├───c\n",
      "    │   │   │   │   │       │   ├───█\n",
      "    │   │   │   │   │       │   └───█\n",
      "    │   │   │   │   │       └───d\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───g\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───u\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───c\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───t\n",
      "    │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───d\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───o\n",
      "    │   │       ├───n\n",
      "    │   │       │   ├───a\n",
      "    │   │       │   │   ├───m\n",
      "    │   │       │   │   │   ├───y\n",
      "    │   │       │   │   │   │   ├───c\n",
      "    │   │       │   │   │   │   │   ├───█\n",
      "    │   │       │   │   │   │   │   └───█\n",
      "    │   │       │   │   │   │   └───d\n",
      "    │   │       │   │   │   │       ├───█\n",
      "    │   │       │   │   │   │       └───█\n",
      "    │   │       │   │   │   └───b\n",
      "    │   │       │   │   │       ├───█\n",
      "    │   │       │   │   │       └───█\n",
      "    │   │       │   │   └───c\n",
      "    │   │       │   │       ├───i\n",
      "    │   │       │   │       │   ├───█\n",
      "    │   │       │   │       │   └───█\n",
      "    │   │       │   │       └───m\n",
      "    │   │       │   │           ├───f\n",
      "    │   │       │   │           │   ├───█\n",
      "    │   │       │   │           │   └───█\n",
      "    │   │       │   │           └───b\n",
      "    │   │       │   │               ├───█\n",
      "    │   │       │   │               └───█\n",
      "    │   │       │   ├───a\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   └───g\n",
      "    │   │       │   │       ├───█\n",
      "    │   │       │   │       └───█\n",
      "    │   │       │   └───█\n",
      "    │   │       ├───█\n",
      "    │   │       ├───n\n",
      "    │   │       │   ├───s\n",
      "    │   │       │   │   ├───a\n",
      "    │   │       │   │   │   ├───█\n",
      "    │   │       │   │   │   └───c\n",
      "    │   │       │   │   │       ├───█\n",
      "    │   │       │   │   │       └───r\n",
      "    │   │       │   │   │           ├───█\n",
      "    │   │       │   │   │           └───█\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   └───█\n",
      "    │   │       │   ├───█\n",
      "    │   │       │   └───█\n",
      "    │   │       └───k\n",
      "    │   │           ├───█\n",
      "    │   │           └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───o\n",
      "    │   │   │   │   │   ├───w\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───p\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───y\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───g\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───i\n",
      "    │   │   │       ├───o\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───m\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   └───m\n",
      "    │   │       ├───█\n",
      "    │   │       └───n\n",
      "    │   │           ├───█\n",
      "    │   │           └───█\n",
      "    │   ├───l\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───t\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   │   ├───m\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───p\n",
      "    │   │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───s\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───p\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───s\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───s\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───m\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───s\n",
      "    │   │   │   │       ├───a\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───c\n",
      "    │   │   │   │       │       ├───█\n",
      "    │   │   │   │       │       └───█\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───h\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───d\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───f\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───g\n",
      "    │   │   │   │   │               ├───█\n",
      "    │   │   │   │   │               └───n\n",
      "    │   │   │   │   │                   ├───█\n",
      "    │   │   │   │   │                   └───█\n",
      "    │   │   │   │   └───a\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───h\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───d\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───o\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   └───v\n",
      "    │   │   │   │       ├───j\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───b\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───n\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───c\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───h\n",
      "    │   │   │           ├───█\n",
      "    │   │   │           └───s\n",
      "    │   │   │               ├───█\n",
      "    │   │   │               └───t\n",
      "    │   │   │                   ├───█\n",
      "    │   │   │                   └───w\n",
      "    │   │   │                       ├───█\n",
      "    │   │   │                       └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───f\n",
      "    │   │   │       ├───h\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───h\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───m\n",
      "    │   │   │           ├───█\n",
      "    │   │   │           └───r\n",
      "    │   │   │               ├───█\n",
      "    │   │   │               └───█\n",
      "    │   │   └───f\n",
      "    │   │       ├───n\n",
      "    │   │       │   ├───a\n",
      "    │   │       │   │   ├───d\n",
      "    │   │       │   │   │   ├───█\n",
      "    │   │       │   │   │   └───k\n",
      "    │   │       │   │   │       ├───█\n",
      "    │   │       │   │   │       └───█\n",
      "    │   │       │   │   └───█\n",
      "    │   │       │   ├───█\n",
      "    │   │       │   └───█\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───d\n",
      "    │   │   ├───k\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───p\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───s\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───m\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───p\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   └───f\n",
      "    │   │       ├───█\n",
      "    │   │       └───n\n",
      "    │   │           ├───█\n",
      "    │   │           └───s\n",
      "    │   │               ├───█\n",
      "    │   │               └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───t\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───l\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───d\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───d\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───f\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───k\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   └───g\n",
      "    │       ├───█\n",
      "    │       └───h\n",
      "    │           ├───█\n",
      "    │           └───█\n",
      "    ├───e\n",
      "    │   ├───i\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───p\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───o\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───j\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───h\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───d\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───p\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───g\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───i\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───l\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───g\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───i\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───o\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───p\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───h\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───d\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───d\n",
      "    │   │   │       ├───a\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───f\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───l\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───f\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───h\n",
      "    │   │   ├───m\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───g\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───b\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   └───s\n",
      "    │   │       ├───█\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───n\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───g\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───d\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───f\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───i\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───g\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───g\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───o\n",
      "    │   │   ├───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   └───n\n",
      "    │       ├───█\n",
      "    │       └───█\n",
      "    ├───e\n",
      "    │   ├───i\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───a\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───s\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───m\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───f\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───r\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───f\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───g\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───c\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───b\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───g\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───f\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───u\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───c\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───m\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───m\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───a\n",
      "    │   │       ├───█\n",
      "    │   │       └───c\n",
      "    │   │           ├───█\n",
      "    │   │           └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───a\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───s\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───c\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───c\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───d\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───j\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───p\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───a\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───d\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───d\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───o\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───s\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───p\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───o\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───c\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───m\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───a\n",
      "    │   │       ├───█\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   └───█\n",
      "    ├───e\n",
      "    │   ├───o\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───g\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───h\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───h\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───r\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───h\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───m\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───u\n",
      "    │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───g\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───g\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───h\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───g\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───r\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───k\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───t\n",
      "    │   │   │   │       ├───a\n",
      "    │   │   │   │       │   ├───v\n",
      "    │   │   │   │       │   │   ├───█\n",
      "    │   │   │   │       │   │   └───█\n",
      "    │   │   │   │       │   └───g\n",
      "    │   │   │   │       │       ├───█\n",
      "    │   │   │   │       │       └───█\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───l\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───m\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───m\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───s\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───t\n",
      "    │   │   │       ├───d\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───m\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───w\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───a\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───h\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───m\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───p\n",
      "    │   │   │   │       ├───d\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───r\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───t\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───r\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───f\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───m\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───u\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───m\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───s\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───f\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───g\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───r\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───t\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───d\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       ├───c\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       ├───l\n",
      "    │   │   │   │       │   ├───i\n",
      "    │   │   │   │       │   │   ├───k\n",
      "    │   │   │   │       │   │   │   ├───█\n",
      "    │   │   │   │       │   │   │   └───█\n",
      "    │   │   │   │       │   │   └───█\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───a\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───d\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───d\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───s\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───m\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───u\n",
      "    │   │   │   │   ├───o\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───h\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───s\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───█\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───k\n",
      "    │   │   │   │       ├───d\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───l\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───g\n",
      "    │   │   │   │   │   ├───m\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───o\n",
      "    │   │   │   │   │   ├───g\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───c\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───j\n",
      "    │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │           └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───d\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───n\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───l\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───s\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       └───i\n",
      "    │   │   │           ├───n\n",
      "    │   │   │           │   ├───█\n",
      "    │   │   │           │   └───█\n",
      "    │   │   │           └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───g\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   └───d\n",
      "    │   │       ├───█\n",
      "    │   │       ├───r\n",
      "    │   │       │   ├───t\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   └───█\n",
      "    │   │       │   ├───p\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   ├───█\n",
      "    │   │       │   │   └───█\n",
      "    │   │       │   └───█\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───l\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───n\n",
      "    │   │       ├───█\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───c\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───o\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───h\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───l\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───k\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───j\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───o\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───d\n",
      "    │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───p\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───i\n",
      "    │   │   │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   └───f\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───l\n",
      "    │   │   │   │   │   │   │           ├───█\n",
      "    │   │   │   │   │   │   │           └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───a\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───d\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───l\n",
      "    │   │   │   │   │   ├───i\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───p\n",
      "    │   │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   │   ├───m\n",
      "    │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───i\n",
      "    │   │   │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │   │   │       └───█\n",
      "    │   │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───d\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───i\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───l\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───f\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───f\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───n\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───o\n",
      "    │   │   │   │   │   ├───f\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───a\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───m\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───k\n",
      "    │   │   │   │           ├───█\n",
      "    │   │   │   │           └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───a\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───g\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───p\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───i\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───a\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───a\n",
      "    │   │       ├───█\n",
      "    │   │       └───b\n",
      "    │   │           ├───█\n",
      "    │   │           └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───c\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───c\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───h\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───a\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───p\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───i\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───m\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───h\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───g\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───s\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───h\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───s\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───g\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───l\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───g\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       ├───d\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───g\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───p\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───b\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───c\n",
      "    │   │   │   │       ├───f\n",
      "    │   │   │   │       │   ├───█\n",
      "    │   │   │   │       │   └───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───k\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───u\n",
      "    │   │   │   ├───v\n",
      "    │   │   │   │   ├───m\n",
      "    │   │   │   │   │   ├───a\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───c\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───v\n",
      "    │   │   │   ├───h\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───t\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───d\n",
      "    │   │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   │   └───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───d\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───s\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───g\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───f\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───s\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───f\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───a\n",
      "    │   │   │       ├───d\n",
      "    │   │   │       │   ├───█\n",
      "    │   │   │       │   └───█\n",
      "    │   │   │       └───l\n",
      "    │   │   │           ├───█\n",
      "    │   │   │           └───█\n",
      "    │   │   └───█\n",
      "    │   ├───v\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───d\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───d\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───b\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───f\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───c\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───f\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───s\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───i\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───d\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───i\n",
      "    │   │   │   │   │       ├───█\n",
      "    │   │   │   │   │       └───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───c\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   └───█\n",
      "    ├───e\n",
      "    │   ├───t\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───u\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───d\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───m\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───n\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───u\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───a\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───█\n",
      "    │   ├───c\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───b\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───g\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───p\n"
     ]
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "    │   │   │   │   ├───a\n",
      "    │   │   │   │   │   ├───█\n",
      "    │   │   │   │   │   └───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───f\n",
      "    │   │   │   │       ├───█\n",
      "    │   │   │   │       └───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───j\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───p\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───t\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───g\n",
      "    │   │   │       ├───█\n",
      "    │   │   │       └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───f\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───m\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───s\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───l\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   ├───m\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───g\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───d\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   └───█\n",
      "    ├───e\n",
      "    │   ├───a\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───l\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   ├───a\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───o\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───c\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───t\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───a\n",
      "    │   │       ├───█\n",
      "    │   │       └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───t\n",
      "    │   │   ├───█\n",
      "    │   │   ├───i\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───g\n",
      "    │   │   │   │   ├───█\n",
      "    │   │   │   │   └───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───r\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───m\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───l\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───g\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   └───█\n",
      "    ├───n\n",
      "    │   ├───c\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───i\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───d\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───e\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   └───█\n",
      "    ├───n\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───e\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───s\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   └───█\n",
      "    ├───i\n",
      "    │   ├───e\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───v\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───n\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───e\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───a\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───p\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───e\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───e\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───c\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───b\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   ├───s\n",
      "    │   │   │   ├───█\n",
      "    │   │   │   └───█\n",
      "    │   │   └───█\n",
      "    │   ├───n\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───o\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───r\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───e\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───a\n",
      "    │   │   ├───█\n",
      "    │   │   └───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   ├───█\n",
      "    │   └───a\n",
      "    │       ├───█\n",
      "    │       └───█\n",
      "    ├───a\n",
      "    │   ├───█\n",
      "    │   └───█\n",
      "    └───█\n"
     ]
    }
   ],
   "source": [
    "max_depth = 10\n",
    "dtID3 = mdt.Tree( min_leaf_size = 1, max_depth = max_depth )\n",
    "dtID3.train( words, get_split_actor, get_leaf_actor, is_pure_enough, get_size, verbose = True )\n",
    "\n",
    "with open( \"dt.mdl\", \"wb\" ) as f:\n",
    "    pickle.dump( dtID3, f )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "id": "f429be40",
   "metadata": {},
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Start  : _ _ _ _ _ _\n",
      "Guess e: _ _ _ _ _ _\n",
      "Guess o: _ _ _ _ _ _\n",
      "Guess i: _ i _ i _ _\n",
      "Guess n: _ i n i _ _\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "['finish']"
      ]
     },
     "execution_count": 6,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "dtID3.predict( [ [] ] )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "id": "8acc2334",
   "metadata": {},
   "outputs": [],
   "source": [
    "def preprocess_data( data ):\n",
    "    X_raw = data[:,:-1]\n",
    "    y_raw = data[:,-1]\n",
    "    \n",
    "    X = np.cumprod( np.flip( 2 * X_raw - 1 , axis = 1 ), axis = 1 )\n",
    "    y = np.where( y_raw > 0, 1, -1 )\n",
    "    \n",
    "    return ( X, y )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "id": "8573fff4",
   "metadata": {},
   "outputs": [],
   "source": [
    "data = np.loadtxt( \"APUF_CRP.txt\" )\n",
    "\n",
    "data_trn, data_tst = train_test_split( data, train_size = 10000 )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 9,
   "id": "0ffda907",
   "metadata": {},
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "C:\\Users\\purus\\AppData\\Local\\Programs\\Python\\Python310\\lib\\site-packages\\sklearn\\svm\\_base.py:1225: ConvergenceWarning: Liblinear failed to converge, increase the number of iterations.\n",
      "  warnings.warn(\n"
     ]
    },
    {
     "data": {
      "text/plain": [
       "0.9948888888888889"
      ]
     },
     "execution_count": 9,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "( X, y ) = preprocess_data( data_trn )\n",
    "( X_t, y_t ) = preprocess_data( data_tst )\n",
    "\n",
    "clf = LinearSVC( loss = \"hinge\" )\n",
    "clf.fit( X, y )\n",
    "\n",
    "w = clf.coef_.reshape( (32,) )\n",
    "b = clf.intercept_\n",
    "temp = X_t.dot(w) + b\n",
    "y_t_pred = np.where( temp > 0, 1, -1 )\n",
    "\n",
    "np.average( y_t == y_t_pred )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 10,
   "id": "5bb61653",
   "metadata": {},
   "outputs": [],
   "source": [
    "class PUF_split_actor:\n",
    "    def __init__( self, attr, pop_label ):\n",
    "        self.attr = attr\n",
    "        self.pop_label = pop_label\n",
    "        \n",
    "    def get_attr( self ):\n",
    "        return self.attr\n",
    "    \n",
    "    def split( self, tst_pts, ancestors ):\n",
    "        split_dict = {}\n",
    "        \n",
    "#         print( len( tst_pts ), end = '' )\n",
    "        \n",
    "        for val in np.unique( tst_pts[ :, self.attr ] ):\n",
    "            idx = np.where( tst_pts[ :, self.attr ] == val )[0].tolist()\n",
    "            split_dict[ val ] = ( idx, tst_pts[ idx, : ]  )\n",
    "#             print( \"[\",idx,\"]\", end = '' )\n",
    "        \n",
    "#         print()\n",
    "        return split_dict\n",
    "        \n",
    "    def default_predict( self, tst_pts, ancestors ):\n",
    "        preds = []\n",
    "        \n",
    "        for x in tst_pts:\n",
    "            preds.append( self.pop_label )\n",
    "        \n",
    "        return preds\n",
    "    \n",
    "class PUF_leaf_actor:\n",
    "    def __init__( self, pop_label ):\n",
    "        self.pop_label = pop_label\n",
    "        \n",
    "    def predict( self, tst_pts, ancestors ):\n",
    "        preds = []\n",
    "        \n",
    "        for x in tst_pts:\n",
    "            preds.append( self.pop_label )\n",
    "        \n",
    "        return preds\n",
    "        \n",
    "    def default_predict( self, tst_pt, ancestors ):\n",
    "        return self.predict( tst_pts, ancestors )\n",
    "\n",
    "def get_PUF_size( trn_pts ):\n",
    "    return len( trn_pts[ 1 ] )\n",
    "\n",
    "def is_PUF_pure_enough( trn_pts ):\n",
    "    labels = trn_pts[ 1 ]\n",
    "    # Pure enough for us if the labels are more than 99% pure\n",
    "    # Since labels are +1/-1 valued this will happen exactly\n",
    "    # when the average label has a magnitude greater than\n",
    "    # 0.99 - (1 - 0.99)) = 0.98\n",
    "    # Similarly, to get 95% purity, we should ask for the\n",
    "    # magtinude to be greater than 0.95 - (1 - 0.95) = 0.90\n",
    "    if np.abs( np.mean( labels ) ) > 0.98:\n",
    "        return True\n",
    "    else:\n",
    "        return False\n",
    "\n",
    "def get_PUF_leaf_actor( trn_pts, ancestors ):\n",
    "    labels = trn_pts[ 1 ]\n",
    "    ( classes, counts ) = np.unique( labels, return_counts = True )    \n",
    "    return PUF_leaf_actor( pop_label = classes[ np.argmax( counts ) ] )\n",
    "\n",
    "# See the following StackOverflow conversation on some alternate ways to compute entropy\n",
    "# https://stackoverflow.com/questions/15450192/fastest-way-to-compute-entropy-in-python\n",
    "def get_PUF_entropy( labels ):    \n",
    "    \n",
    "    _, counts = np.unique( labels, return_counts = True )\n",
    "    \n",
    "    # Why include elements that do not appear at all?\n",
    "    assert np.min( counts ) > 0, \"Elements with zero or negative counts detected\"\n",
    "    \n",
    "    num_elements = counts.sum()\n",
    "    \n",
    "    # A singular or empty set has zero entropy\n",
    "    if num_elements <= 1:\n",
    "#         print( f\"warning: { num_elements } elements in total\" )\n",
    "        return 0\n",
    "    \n",
    "    proportions = counts / num_elements\n",
    "    \n",
    "    return -np.sum( proportions * np.log2( proportions ) )\n",
    "\n",
    "def try_PUF_attr( a, X, y ):\n",
    "    n = len( y )\n",
    "    assert n == X.shape[ 0 ], \"Mismatch in number of features and number of labels\"\n",
    "    \n",
    "    split_dict = {}\n",
    "    entropy = 0\n",
    "        \n",
    "    for val in np.unique( X[ :, a ] ):\n",
    "        # Find out who all would go to this child\n",
    "        idx = np.where( X[ :, a ] == val )[0].tolist()\n",
    "        split_dict[ val ] = ( X[ idx, : ], y[ idx ] )\n",
    "        # Calculate the entropy of the child\n",
    "        entropy += len(idx) / n * get_PUF_entropy( y[ idx ] )\n",
    "    \n",
    "    return ( entropy, split_dict )\n",
    "\n",
    "def get_PUF_split_actor( trn_pts, ancestors ):\n",
    "    ( X, y ) = trn_pts\n",
    "    ( n, d ) = X.shape\n",
    "    \n",
    "    # Exclude the attribute used by my parent to split my siblings and me\n",
    "    if len( ancestors ) < 1:\n",
    "        parent_attr = -1\n",
    "    else:\n",
    "        parent_attr = ancestors[-1][0]\n",
    "    \n",
    "    best_entropy = np.inf\n",
    "    best_attr = -1\n",
    "    best_split_dict = None\n",
    "    \n",
    "    for a in [ attr for attr in np.arange( d ) if not attr == parent_attr ]:\n",
    "        ( entropy, split_dict ) = try_PUF_attr( a, X, y )\n",
    "#         print( f\"{a}({entropy})\", end = \", \" )\n",
    "        if entropy < best_entropy:\n",
    "            best_entropy = entropy\n",
    "            best_attr = a\n",
    "            best_split_dict = split_dict\n",
    "    \n",
    "#     print()\n",
    "    \n",
    "#     print( f\"\\n\\n\\n{best_attr}({best_entropy})\" )\n",
    "    ( classes, counts ) = np.unique( y, return_counts = True )\n",
    "#     print( f\"\\n\\n\\n{ counts } --> \", end = '' )\n",
    "    for ( XX, yy ) in best_split_dict.values():\n",
    "        ( _, cc ) = np.unique( yy, return_counts = True )\n",
    "#         print( f\"{ cc }, \", end = '' )\n",
    "    \n",
    "    pop_label = classes[ np.argmax( counts ) ]\n",
    "    return ( PUF_split_actor( best_attr, pop_label ), best_split_dict )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 11,
   "id": "5a5834e9",
   "metadata": {
    "scrolled": true
   },
   "outputs": [],
   "source": [
    "max_depth = 15\n",
    "\n",
    "dt_PUF = mdt.Tree( min_leaf_size = 1, max_depth = max_depth )\n",
    "dt_PUF.train( ( X, y ), get_PUF_split_actor, get_PUF_leaf_actor, is_PUF_pure_enough, get_PUF_size )\n",
    "\n",
    "with open( \"dt_PUF.mdl\", \"wb\" ) as f:\n",
    "    pickle.dump( dt_PUF, f )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 12,
   "id": "7023c346",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "0.999"
      ]
     },
     "execution_count": 12,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Training accuracy\n",
    "y_pred = np.array( dt_PUF.predict( X ) )\n",
    "np.average( y == y_pred )"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 13,
   "id": "4c199c4e",
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "0.8152"
      ]
     },
     "execution_count": 13,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# Test accuracy\n",
    "y_t_pred = np.array( dt_PUF.predict( X_t ) )\n",
    "np.average( y_t == y_t_pred )"
   ]
  }
 ],
 "metadata": {
  "author": {
   "email": "purushot@cse.iitk.ac.in",
   "institution": "IIT Kanpur",
   "name": "Puru"
  },
  "kernelspec": {
   "display_name": "Python 3 (ipykernel)",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.10.5"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 5
}
